# Changelog

## [0.3.0] - 24 July 2020

### Changed

- line_pattern.get_value can return matches of multiple regexp words.


## [0.2.0] - 22 July 2020

### Changed

- Minor changes in API Hocron class receives a string instead of a file path
- Hocron class has only one function - extract

## [0.1.0] - 15 June 2020

### very first hocron commit

